@@ -154,11 +154,10 @@ def db_del_dict_from_mongodb(mongo_db_name: str, col_name: str, query_dict: dict
     return x.deleted_count
 
 
-def get_trade_cal_from_ts(start_date: str = '20000101', end_date: str = None):
-    pro = const.TS_PRO
+def get_trade_cal_from_ts(ts_pro_token, start_date: str = '20000101', end_date: str = None):
     if end_date is None:
         end_date = date.today().strftime('%Y%m%d')
-    df_trade_cal = pro.trade_cal(**{
+    df_trade_cal = ts_pro_token.trade_cal(**{
         "exchange": "SSE",
         "cal_date": "",
         "start_date": start_date,
